@@ -26,7 +26,7 @@ extern "C" {
 #include <assert.h>
 
 #if !defined(WIN32)
-#    include <sys/resource.h>		/* getrlimit               */
+#    include <sys/resource.h>	/* getrlimit               */
 #    include <syslog.h>
 #endif
 }
@@ -78,7 +78,7 @@ public:
 	GenServer ();
 
 	/// Destructor
-	virtual ~GenServer() {}
+	virtual ~GenServer ();
 
 	/** Provide an entry point into the service and perfom initialization 
 	    of the service.
@@ -337,6 +337,22 @@ private:
 	void init_internals ();
 };
 
+/** Reactor needs to *detach* itself from the Logger
+ *  before releasing memory. Otherwise, a race condition
+ *  between Logger (singleton) and GenServer (singleton)
+ *  might yield core dump if Reactor was destroyed 
+ *  before Logger. Since Reactor is *attached* to the Logger
+ *  with Logger::log_open () for the assa-logd connection, it is
+ *  Reactor's responsibility to *detach* first. But, we only care
+ *  about GenServer's Reactor. All others (such as those used by
+ *  Connector and Acceptor classes) should not.
+ */
+inline
+GenServer::
+~GenServer ()
+{
+	Log::log_close ();
+}
 
 inline void
 GenServer::
