@@ -51,14 +51,6 @@ Reactor () :
 #endif
 }
 
-/** Reactor needs to *detach* itself from the Logger
- *  before releasing memory. Otherwise, a race condition
- *  between Logger (singleton) and GenServer (singleton)
- *  might yield core dump if Reactor has been destroyed 
- *  before Logger. Since Reactor is *attached* to the Logger
- *  with Logger::log_open () for the assa-logd connection, it is
- *  Reactor's responsibility to *detach* first.
- */
 Reactor::
 ~Reactor()
 {	
@@ -67,7 +59,6 @@ Reactor::
     m_readSet.clear   ();
     m_writeSet.clear  ();
     m_exceptSet.clear ();
-	Log::log_close ();
 	deactivate ();
 }
 
@@ -247,8 +238,7 @@ removeHandler (EventHandler* eh_, EventType event_)
 	}
 
 	if (ret == true) {
-		DL((REACT,"Found EvtH \"%s\"(0x%X)\n", 
-			eh_->get_id ().c_str (),int(eh_)));
+		DL((REACT,"Found EvtH \"%s\"(%p)\n", eh_->get_id ().c_str (), eh_));
 		eh_->handle_close (fd);
 	}
 
@@ -327,8 +317,7 @@ removeIOHandler (handler_t fd_)
 	}
 
 	if (ret == true && ehp != NULL) {
-		DL((REACT,"Removed EvtH \"%s\"(0x%X)\n", 
-			ehp->get_id ().c_str (), int(ehp)));
+		DL((REACT,"Removed EvtH \"%s\"(%p)\n", ehp->get_id ().c_str (), ehp));
 		ehp->handle_close (fd_);
 	}
 
